[![Build Status](https://github.com/dbbs-lab/bsb/actions/workflows/main.yml/badge.svg)](https://github.com/dbbs-lab/bsb/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/bsb-core/badge/?version=latest)](https://bsb-core.readthedocs.io/en/latest/?badge=latest)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![codecov](https://codecov.io/gh/dbbs-lab/bsb-core/branch/main/graph/badge.svg)](https://codecov.io/gh/dbbs-lab/bsb-core)

# bsb-core

This project contains the main [BSB](https://github.com/dbbs-lab/bsb) framework and is needed by all its sub packages.

Comprehensive documentation is available at:

* [BSB Documentation](https://bsb.readthedocs.io/en/latest)
* [bsb-core Documentation](https://bsb-core.readthedocs.io/en/latest)
